@@ -302,6 +302,12 @@ void FBReader::openBook(shared_ptr<Book> book) {
 
 void FBReader::openBookInternal(shared_ptr<Book> book) {
 	if (!book.isNull()) {
+		if ((!myModel.isNull()) && (book->filePath() == myModel->book()->filePath())) {
+			closeView();
+			refreshWindow();
+			return;
+		}
+
 		BookTextView &bookTextView = (BookTextView&)*myBookTextView;
 		ContentsView &contentsView = (ContentsView&)*myContentsView;
 		FootnoteView &footnoteView = (FootnoteView&)*myFootnoteView;
